TRANSLATION = {
    'pmwuserscounter': 'users counter',
    'pmwprojectscounter': 'projects counter',
    'pmwtemplatescounter': 'templates counter',
    'pmwinventoriescounter': 'inventories counter',
    'pmwgroupscounter': 'groups counter',
    'pmwhostscounter': 'hosts counter',
    'pmwchartwidget': 'chart widget',

    'templates counter': 'templates | template | templates',
    'projects counter': 'projects | project | projects',
    'inventories counter': 'inventories | inventory | inventories',
    'groups counter': 'groups | group | groups',
    'hosts counter': 'hosts | host | hosts',
    'users counter': 'users | user | users',
    'execution_plugins counter': 'execution plugins | execution plugin | execution plugins',
    'inventory_plugins counter': 'inventory plugins | inventory plugin | inventory plugins',
    'all_tasks': 'all tasks',

    'Acl': 'ACL'
}
